##  Step 5: Define the Completion Status
Specify which Jira work item statuses to treat as “completed” in SAP LeanIX. This helps track issue progress within SAP LeanIX dashboards.
To set your preferred statuses, do the following:
  1. Under Configure Completion Status, select a status from the Status dropdown.
For example, Released or Done.
  2. Choose Save.
